@@ -45,44 +45,60 @@ fn can_read_full_config() {
             assert_eq!(distribution_factor, Some(0.25));
             assert_eq!(learning_rate, Some(0.1));
             assert_eq!(rebalance_memory, Some(500));
-            assert_eq!(rebalance_count, Some(10));
+            assert_eq!(rebalance_count, Some(4));
             assert_eq!(exploration_ratio, Some(0.9));
         }
-        PopulationType::Elitism { .. } => unreachable!(),
+        _ => unreachable!(),
     }
 
-    let mutation_config = config.mutation.expect("cannot get mutation");
-    match mutation_config {
-        MutationType::Composite { inners, .. } => {
-            assert_eq!(inners.len(), 3);
-            match inners.first().unwrap() {
+    let hyper_config = config.hyper.expect("cannot get hyper");
+    match hyper_config {
+        HyperType::StaticSelective { mutations } => {
+            assert_eq!(mutations.len(), 4);
+            match mutations.first().unwrap() {
+                MutationType::Decomposition { routes, repeat, probability } => {
+                    assert_eq!(*repeat, 4);
+                    assert_eq!(routes.min, 2);
+                    assert_eq!(routes.max, 4);
+                    match probability {
+                        MutationProbabilityType::Context { threshold, phases } => {
+                            assert_eq!(threshold.jobs, 300);
+                            assert_eq!(threshold.routes, 10);
+                            assert_eq!(phases.len(), 2);
+                        }
+                        _ => unreachable!(),
+                    }
+                }
+                _ => unreachable!(),
+            }
+
+            match mutations.get(1).unwrap() {
                 MutationType::LocalSearch { probability, times, operators: inners } => {
-                    assert_eq!(*probability, 0.05);
+                    assert_eq!(as_scalar_probability(probability), 0.05);
                     assert_eq!(*times, MinMaxConfig { min: 1, max: 2 });
                     assert_eq!(inners.len(), 3);
                 }
                 _ => unreachable!(),
             }
 
-            match inners.get(1).unwrap() {
+            match mutations.get(2).unwrap() {
                 MutationType::RuinRecreate { probability, ruins, recreates } => {
-                    assert_eq!(*probability, 1.);
+                    assert_eq!(as_scalar_probability(probability), 1.);
                     assert_eq!(ruins.len(), 6);
                     assert_eq!(recreates.len(), 10);
                 }
                 _ => unreachable!(),
             }
 
-            match inners.last().unwrap() {
+            match mutations.last().unwrap() {
                 MutationType::LocalSearch { probability, times, operators: inners } => {
-                    assert_eq!(*probability, 0.01);
+                    assert_eq!(as_scalar_probability(probability), 0.01);
                     assert_eq!(*times, MinMaxConfig { min: 1, max: 2 });
                     assert_eq!(inners.len(), 3);
                 }
                 _ => unreachable!(),
             }
         }
-        _ => unreachable!(),
     }
 
     let termination = config.termination.expect("no termination config");
@@ -116,7 +132,14 @@ fn can_create_default_config() {
     let config = Config::default();
 
     assert!(config.evolution.is_none());
-    assert!(config.mutation.is_none());
+    assert!(config.hyper.is_none());
     assert!(config.termination.is_none());
     assert!(config.telemetry.is_none());
 }
+
+fn as_scalar_probability(probability: &MutationProbabilityType) -> f64 {
+    match probability {
+        MutationProbabilityType::Scalar { scalar } => *scalar,
+        _ => unreachable!(),
+    }
+}
